@@ -4,6 +4,43 @@ from deploy_config_generator.utils import yaml_dump
 from deploy_config_generator.output import kube_common
 
 
+INGRESS_BACKEND_FIELD_SPEC = dict(
+    resource=dict(
+        type='dict',
+        fields=dict(
+            api_group=dict(
+                type='str',
+            ),
+            kind=dict(
+                type='str',
+            ),
+            name=dict(
+                type='str',
+            ),
+        ),
+    ),
+    service=dict(
+        type='dict',
+        fields=dict(
+            name=dict(
+                type='str',
+            ),
+            port=dict(
+                type='dict',
+                fields=dict(
+                    name=dict(
+                        type='str',
+                    ),
+                    number=dict(
+                        type='int',
+                    ),
+                ),
+            ),
+        ),
+    ),
+)
+
+
 class OutputPlugin(kube_common.OutputPlugin):
 
     NAME = 'kube_ingress'
@@ -22,16 +59,9 @@ class OutputPlugin(kube_common.OutputPlugin):
                     type='dict',
                     required=True,
                     fields=dict(
-                        backend=dict(
+                        default_backend=dict(
                             type='dict',
-                            fields=dict(
-                                service_name=dict(
-                                    type='str',
-                                ),
-                                service_port=dict(
-                                    # The port can be a string or an int, so we don't specify a type
-                                ),
-                            ),
+                            fields=copy.deepcopy(INGRESS_BACKEND_FIELD_SPEC),
                         ),
                         rules=dict(
                             type='list',
@@ -49,18 +79,15 @@ class OutputPlugin(kube_common.OutputPlugin):
                                             fields=dict(
                                                 backend=dict(
                                                     type='dict',
-                                                    fields=dict(
-                                                        service_name=dict(
-                                                            type='str',
-                                                        ),
-                                                        service_port=dict(
-                                                            # The port can be a string or an int, so we don't specify the type
-                                                        ),
-                                                    ),
+                                                    fields=copy.deepcopy(INGRESS_BACKEND_FIELD_SPEC),
                                                 ),
                                                 path=dict(
                                                     type='str',
                                                 ),
+                                                path_type=dict(
+                                                    type='str',
+                                                    required=True,
+                                                ),
                                             ),
                                         ),
                                     ),
@@ -89,7 +116,7 @@ class OutputPlugin(kube_common.OutputPlugin):
     def generate_output(self, app_vars):
         # Basic structure
         data = {
-            'apiVersion': 'extensions/v1beta1',
+            'apiVersion': 'networking.k8s.io/v1',
             'kind': 'Ingress',
         }
         data['metadata'] = self.build_metadata(app_vars['APP']['metadata'])
