@@ -37,5 +37,6 @@ class OutputPlugin(kube_common.OutputPlugin):
         data['metadata'] = self.build_metadata(app_vars['APP']['metadata'])
         data['spec'] = self.build_generic(app_vars['APP']['spec'], self._plugin_config['fields']['kube_jobs']['spec']['fields'])
 
-        output = yaml_dump(self._template.render_template(data, app_vars))
-        return output
+        data = self._template.render_template(data, app_vars)
+        output = yaml_dump(data)
+        return (output, self.get_output_filename_suffix(data))
